# Man edit

> edit [subject] - In shell mode, edit the current conversation log. When passed an existing subject as parameter, it will edit that conversation instead.

## Usage

`edit`

`edit game001`